.. py:function:: acosh(x [, ret])

    Wrapper for :c:func:`gsl_acosh`
    c code signature: double gsl_acosh(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: asinh(x [, ret])

    Wrapper for :c:func:`gsl_asinh`
    c code signature: double gsl_asinh(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: atanh(x [, ret])

    Wrapper for :c:func:`gsl_atanh`
    c code signature: double gsl_atanh(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_cos_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_cos_e`
    c code signature: int gsl_sf_cos_e( double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_cos(x [, ret])

    Wrapper for :c:func:`gsl_sf_cos`
    c code signature: double gsl_sf_cos(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_cos_err_e(x, dx [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_cos_err_e`
    c code signature: int gsl_sf_cos_err_e(const double x, const double dx, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double x: positional argument 0
    :param double dx: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_sin_err_e(x, dx [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_sin_err_e`
    c code signature: int gsl_sf_sin_err_e(const double x, const double dx, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double x: positional argument 0
    :param double dx: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_sin_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_sin_e`
    c code signature: int gsl_sf_sin_e( double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_sin(x [, ret])

    Wrapper for :c:func:`gsl_sf_sin`
    c code signature: double gsl_sf_sin(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_sinc(x [, ret])

    Wrapper for :c:func:`gsl_sf_sinc`
    c code signature: double gsl_sf_sinc(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_sinc_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_sinc_e`
    c code signature: int gsl_sf_sinc_e( double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_angle_restrict_pos_err_e(theta [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_angle_restrict_pos_err_e`
    c code signature: int gsl_sf_angle_restrict_pos_err_e(const double theta, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double theta: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_angle_restrict_pos(theta [, ret])

    Wrapper for :c:func:`gsl_sf_angle_restrict_pos`
    c code signature: double gsl_sf_angle_restrict_pos(const double theta)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double theta: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_angle_restrict_symm(theta [, ret])

    Wrapper for :c:func:`gsl_sf_angle_restrict_symm`
    c code signature: double gsl_sf_angle_restrict_symm(const double theta)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double theta: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_angle_restrict_symm_err_e(theta [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_angle_restrict_symm_err_e`
    c code signature: int gsl_sf_angle_restrict_symm_err_e(const double theta, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double theta: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_hypot(x, y [, ret])

    Wrapper for :c:func:`gsl_sf_hypot`
    c code signature: double gsl_sf_hypot(const double x, const double y)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_hypot_e(x, y [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_hypot_e`
    c code signature: int gsl_sf_hypot_e(const double x, const double y, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_lncosh_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_lncosh_e`
    c code signature: int gsl_sf_lncosh_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_lncosh(x [, ret])

    Wrapper for :c:func:`gsl_sf_lncosh`
    c code signature: double gsl_sf_lncosh(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_lnsinh_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_lnsinh_e`
    c code signature: int gsl_sf_lnsinh_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_lnsinh(x [, ret])

    Wrapper for :c:func:`gsl_sf_lnsinh`
    c code signature: double gsl_sf_lnsinh(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

